@@ -11,11 +11,11 @@ import re
 system = platform.system()
 #arch, _ = platform.architecture()
 if system == 'Linux':
-    os='linux'
+    opsys='linux'
 if system == 'Windows':
-    os='win'
+    opsys='win'
 if system == 'Darwin':
-    os='mac'
+    opsys='mac'
 
 # Adds a line to some *data file.
 def add_keyword(keyword, filename:str, params=None):
@@ -46,7 +46,10 @@ def gmin():
         # write output to file
         f = open("gmin_output.txt", "w")
         # execute GMIN binary as defined by setup.py for correct OS
-        subprocess.call(f'bin/{os}/GMIN', stdout=f)
+        if opsys != 'win':
+            subprocess.call(f'bin/{opsys}/GMIN', stdout=f)
+        else:
+            subprocess.call('bin/win/GMIN.exe', stdout=f)
     else:
         print('Data or coords file are missing')		
 
@@ -56,7 +59,10 @@ def optim(outfile='optim_output.txt'):
         # write output to file
         f = open(outfile, "w")
         # execute OPTIM binary as defined by setup.py for correct OS
-        subprocess.call(f'bin/{os}/OPTIM', stdout=f)
+        if opsys != 'win':
+            subprocess.call(f'bin/{opsys}/OPTIM', stdout=f)
+        else:
+            subprocess.call('bin/win/OPTIM.exe', stdout=f)
     else:
         print('odata file is missing')
 
@@ -66,7 +72,10 @@ def pathsample():
         # write output to file
         f = open("pathsample_output.txt", "w")
         # execute PS binary as defined by setup.py for correct OS
-        subprocess.call(f'bin/{os}/PATHSAMPLE', stdout=f)
+        if opsys != 'win':
+            subprocess.call(f'bin/{opsys}/PATHSAMPLE', stdout=f)
+        else:
+            subprocess.call('bin/win/PATHSAMPLE.exe', stdout=f)
     else:
         print('pathdata file is missing')
 
